@@ -9,7 +9,7 @@ requires qw( experimental format );
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.29_09';
+our $VERSION = '0.29_11';
 $VERSION = eval $VERSION; ## no critic
 
 use Carp;
@@ -28,7 +28,7 @@ has 'develop' => (
 sub _develop {
 	my $self = shift;
 
-	if ( $self->experimental && ( $self->format =~ m/cpanfile|metajson/) ) {
+	if ( $self->experimental && ( $self->format =~ m/cpanfile|metajson|dist/) ) {
 		return 1;
 	} else {
 		return 0;
@@ -102,7 +102,7 @@ App::Midgen::Role::Attributes - Package Attributes used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.29_09
+version: 0.29_11
 
 =head1 METHODS
 
