@@ -1,21 +1,20 @@
 package App::Midgen::Role::TestRequires;
 
+use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
+
 use Moo::Role;
 requires qw( ppi_document develop debug format xtest _process_found_modules );
 
 use PPI;
-
 use Try::Tiny;
 use Data::Printer {caller_info => 1, colored => 1,};
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.29_09';
+our $VERSION = '0.29_11';
 $VERSION = eval $VERSION; ## no critic
 
-use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
-
 
 #######
 # composed method - xtests_test_requires
@@ -152,7 +151,7 @@ sub xtests_test_requires {
 	# if we found a module, process it with the correct catogery
 	if (scalar @modules > 0) {
 
-		if ($self->format =~ /cpanfile|metajson/) {
+		if ($self->format =~ /cpanfile|metajson|dist/) {
 			if ($self->xtest eq 'test_requires') {
 				$self->_process_found_modules('recommends', \@modules);
 			}
@@ -184,7 +183,7 @@ for methods in use L<Test::Requires> blocks, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.29_09
+version: 0.29_11
 
 =head1 METHODS
 
